// font-browser.c : demo of font-selector 

#include "font-selector.h"

int main(int argc, char **argv) {
  if (argc > 1) sampstr = argv[1];
  char *mask = (argc > 2) ? argv[2] : (char*) "-*-*-*-*-*-*-*-*-*-*-*-*-*-*";
  xfont_select(mask);
}
